<?php

/**
 * @file
 * Provide views data.
 */

/**
 * Implements hook_views_data().
 */
function rules_link_views_data() {
  $data = array();

  foreach (rules_link_get_links() as $name => $rules_link) {
    $entity = entity_get_info($rules_link->entity_type);
    $data[$entity['base table']][$name]['field'] = array(
      'title' => $rules_link->label,
      'help' => t('Execute the selected rules link.'),
      'handler' => 'views_handler_field_rules_link',
      'real field' => $entity['entity keys']['id'],
      'rules link name' => $name,
    );
  }
  return $data;
}

/**
 * Renders the links for views.
 */
class views_handler_field_rules_link extends views_handler_field {
  function render($value) {
    $replacements = filter_xss_admin($this->options['rules_link']['rules_link_parameters']);
    $token = $this->get_render_tokens('');
    $parameters = explode(',', strtr($replacements, $token));

    // Trim the spaces from the
    array_walk($parameters, 'rules_link_trim_parameters');

    $rules_link = rules_link_load($this->definition['rules link name']);
    $info = entity_get_info($rules_link->entity_type);
    if (count($info['bundles']) > 1) {
      $entity = entity_load_single($rules_link->entity_type, $this->get_value($value));
      if (in_array($entity->type, $rules_link->settings['bundles'])) {
        return rules_link_render_link($rules_link, $this->get_value($value), drupal_get_destination(), $parameters);
      }
    }
    else {
      return rules_link_render_link($rules_link, $this->get_value($value), drupal_get_destination(), $parameters);
    }
  }

  /**
   * Override option_definition.
   */
  function option_definition() {
    $options = parent::option_definition();
    $options['rules_link']['rules_link_parameters'] = array('default' => '');
    return $options;
  }

  /**
   * Override options_form.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    $form['rules_link'] = array(
      '#type' => 'fieldset',
      '#title' => t('Rules Link settings'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['rules_link']['rules_link_parameters'] = array(
      '#type' => 'textfield',
      '#title' => t('Additional parameters for the rules link'),
      '#description' => t('Enter additional parameter using replacement patterns, use comma to enter multiple items. Whitespaces at the beginning and end of token will be trimmed.'),
      '#default_value' => $this->options['rules_link']['rules_link_parameters'],
    );
    $form['rules_link']['rules_link_patterns'] = array(
      '#type' => 'fieldset',
      '#title' => t('Replacement patterns'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#value' => $form['alter']['help']['#value'],
    );
  }
}
